from .air_selenium import AirSelenium
from DatabaseLibrary import DatabaseLibrary as AirDatabase
from AppiumLibrary import AppiumLibrary as AirAppium
from DiffLibrary import DiffLibrary as AirDiff
from RequestsLibrary import RequestsLibrary as AirRequests
from ArchiveLibrary import ArchiveLibrary as AirArchive
from FtpLibrary import FtpLibrary as AirFtp
